@@ -5,8 +5,8 @@ from openconnect_sso.browser import Browser
 log = structlog.get_logger()
 
 
-async def authenticate_in_browser(auth_info, credentials):
-    async with Browser() as browser:
+async def authenticate_in_browser(proxy, auth_info, credentials, display_mode):
+    async with Browser(proxy, display_mode) as browser:
         await browser.authenticate_at(auth_info.login_url, credentials)
 
         while browser.url != auth_info.login_final_url:
